@@ -30,6 +30,7 @@ def api_v4(self):
     zones_settings(self)
     zones_spectrum(self)
     zones_ssl(self)
+    zones_waiting_rooms(self)
     zones_workers(self)
 
     # The API commands for /railguns/
@@ -46,6 +47,7 @@ def api_v4(self):
     accounts_access(self)
     accounts_addressing(self)
     accounts_audit_logs(self)
+    accounts_diagnostics(self)
     accounts_firewall(self)
     accounts_load_balancers(self)
     accounts_secondary_dns(self)
@@ -98,6 +100,8 @@ def zones(self):
     self.add('AUTH', "zones", "purge_cache")
     self.add('AUTH', "zones", "railguns")
     self.add('AUTH', "zones", "railguns", "diagnose")
+    self.add('AUTH', 'zones', 'rulesets')
+    self.add('AUTH', 'zones', 'rulesets', 'versions')
     self.add('VOID', "zones", "security")
     self.add('AUTH', "zones", "security/events")
     self.add('AUTH', "zones", "subscription")
@@ -305,10 +309,12 @@ def user_load_balancers(self):
     self.add('VOID', "user/load_balancers")
     self.add('AUTH', "user/load_balancers/monitors")
     self.add('AUTH', "user/load_balancers/monitors", "preview")
+    self.add('AUTH', 'user/load_balancers/monitors', 'references')
     self.add('AUTH', "user/load_balancers/preview")
     self.add('AUTH', "user/load_balancers/pools")
     self.add('AUTH', "user/load_balancers/pools", "health")
     self.add('AUTH', "user/load_balancers/pools", "preview")
+    self.add('AUTH', 'user/load_balancers/pools', 'references')
 
 def user_workers(self):
     """ API core commands for Cloudflare API"""
@@ -352,6 +358,9 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'rules/lists')
     self.add('AUTH', 'accounts', 'rules/lists', 'items')
     self.add('AUTH', 'accounts', 'rules/lists/bulk_operations')
+    self.add('AUTH', 'accounts', 'rulesets')
+    self.add('AUTH', 'accounts', 'rulesets', 'versions')
+    self.add('AUTH', 'accounts', 'rulesets/import')
     self.add('VOID', "accounts", "storage")
     self.add('AUTH', "accounts", "storage/analytics")
     self.add('AUTH', "accounts", "storage/analytics/stored")
@@ -361,12 +370,15 @@ def accounts(self):
     self.add('AUTH', "accounts", "storage/kv/namespaces", "keys")
     self.add('AUTH', "accounts", "storage/kv/namespaces", "values")
     self.add('AUTH', "accounts", "subscriptions")
+    self.add('AUTH', 'accounts', 'tunnels')
+    self.add('AUTH', 'accounts', 'tunnels', 'connections')
     self.add('AUTH', "accounts", "virtual_dns")
     self.add('VOID', "accounts", "virtual_dns", "dns_analytics")
     self.add('AUTH', "accounts", "virtual_dns", "dns_analytics/report")
     self.add('AUTH', "accounts", "virtual_dns", "dns_analytics/report/bytime")
     self.add('VOID', "accounts", "workers")
     self.add('AUTH', "accounts", "workers/scripts")
+    self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
 
 def accounts_addressing(self):
     """ API core commands for Cloudflare API"""
@@ -389,9 +401,12 @@ def accounts_load_balancers(self):
     self.add('AUTH', 'accounts', 'load_balancers/preview')
     self.add('AUTH', "accounts", "load_balancers/monitors")
     self.add('AUTH', 'accounts', 'load_balancers/monitors', 'preview')
+    self.add('AUTH', 'accounts', 'load_balancers/monitors', 'references')
     self.add('AUTH', "accounts", "load_balancers/pools")
     self.add('AUTH', "accounts", "load_balancers/pools", "health")
     self.add('AUTH', 'accounts', 'load_balancers/pools', 'preview')
+    self.add('AUTH', 'accounts', 'load_balancers/pools', 'references')
+    self.add('AUTH', 'accounts', 'load_balancers/regions')
     self.add('AUTH', 'accounts', 'load_balancers/search')
 
 def accounts_firewall(self):
@@ -406,6 +421,7 @@ def accounts_secondary_dns(self):
 
     self.add('VOID', "accounts", "secondary_dns")
     self.add('AUTH', "accounts", "secondary_dns/masters")
+    self.add('AUTH', 'accounts', 'secondary_dns/primaries')
     self.add('AUTH', "accounts", "secondary_dns/tsigs")
 
 def accounts_stream(self):
@@ -472,3 +488,15 @@ def accounts_access(self):
     self.add('AUTH', 'accounts', 'access/apps', 'policies')
     self.add('AUTH', 'accounts', 'access/apps', 'revoke_tokens')
 
+def accounts_diagnostics(self):
+    """ API core commands for Cloudflare API"""
+
+    self.add('VOID', 'accounts', 'diagnostics')
+    self.add('AUTH', 'accounts', 'diagnostics/traceroute')
+
+def zones_waiting_rooms(self):
+    """ API core commands for Cloudflare API"""
+
+    self.add('AUTH', 'zones', 'waiting_rooms')
+    self.add('AUTH', 'zones', 'waiting_rooms', 'status')
+    self.add('AUTH', 'zones', 'waiting_rooms/preview')
